@@ -60,8 +60,8 @@ See F<LICENSE>.
 
 =cut
 
-$^V eq 5.36.1 
-    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.1) ".
+$^V eq 5.38.0 
+    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.0) ".
                    "that PAR::Packer was built with; please rebuild PAR::Packer", 
                    $^X, $^V);
 
@@ -81,8 +81,8 @@ M````(*<````````@IP```````""G````````#`$````````,`0````````0`
 M````````4>5T9`8`````````````````````````````````````````````
 M````````````$`````````!2Y71D!````'"[````````<+L!``````!PNP$`
 M`````)`$````````D`0````````!`````````"]L:6(O;&0M;&EN=7@M86%R
-M8V@V-"YS;RXQ```$````%`````,```!'3E4`C.:$BK^N>O)/=#?N-PR.3(VQ
-M31X$````$`````$```!'3E4```````,````'`````````#L```!*````!```
+M8V@V-"YS;RXQ```$````%`````,```!'3E4`!'JCVHH727F1\8$2-HV(BWXT
+M^?D$````$`````$```!'3E4```````,````'`````````#L```!*````!```
 M``@````A$!``!<`$A"@"$`6`AD"$@HD`!@D@!(B(@!!!N@`""`````!*````
 M3````$T```````````````````!/`````````%````!1````4@``````````
 M````4P```%0`````````````````````````50```%8```!7`````````%@`
@@ -93,39 +93,39 @@ M````?JF<FUGOEWEK"4/6=E0\E"'_Y`X-.I<+P^4_+(D'<-/9<5@<K4OCP&L:
 MGE#59-1\F4_#FR_%F[8S8MOM:W^:?`&O-.B[XY)\LP&+;T+ZUX=#1=7L9Z_,
 M9A6,)<RCX/M)S]Y'+>-'Q@'@IP(*;\7?'[[:5QO[H6Q@````````````````
 M```````````````````````````#``L`V!L````````````````````````#
-M`!8``,`!`````````````````"@!```2`````````````````````````-X!
-M```2`````````````````````````(`````2````````````````````````
-M`+`````2`````````````````````````'D"```2````````````````````
-M`````.4!```2`````````````````````````&4!```2````````````````
+M`!8``,`!``````````````````H!```2`````````````````````````-X!
+M```2`````````````````````````%0!```2````````````````````````
+M`-,````2`````````````````````````'D"```2````````````````````
+M`````.4!```2`````````````````````````.D````2````````````````
 M``````````$````@`````````````````````````*8"```2````````````
 M`````````````*$!```2`````````````````````````*8#```2````````
-M`````````````````*<````2`````````````````````````.D"```1````
-M`````````````````````%,````2`````````````````````````%H"```2
-M`````````````````````````+L````2`````````````````````````"T"
+M`````````````````)H````2`````````````````````````.D"```1````
+M`````````````````````,,````2`````````````````````````%H"```2
+M`````````````````````````",!```2`````````````````````````"T"
 M```2`````````````````````````*$"```2````````````````````````
 M`&$"```2`````````````````````````#4"```2````````````````````
 M`````(8!```B`````````````````````````!`````@````````````````
-M`````````!("```2``````````````````````````@!```2````````````
+M`````````!("```2`````````````````````````-X````2````````````
 M`````````````"P````@``````````````````````````D"```2````````
 M`````````````````/,!```2`````````````````````````&H"```2````
 M`````````````````````,`"```2`````````````````````````%,"```1
-M`````````````````````````#\"```2`````````````````````````'@!
-M```2`````````````````````````/4````6````````````````````````
-M`)<````2`````````````````````````&\````2````````````````````
-M`````!D"```2`````````````````````````%0!```2````````````````
-M`````````-@````2`````````````````````````/L!```2````````````
+M`````````````````````````#\"```2`````````````````````````#$!
+M```2`````````````````````````',!```6````````````````````````
+M`(H````2`````````````````````````$8````2````````````````````
+M`````!D"```2`````````````````````````+(````2````````````````
+M`````````*,````2`````````````````````````/L!```2````````````
 M`````````````)`"```2`````````````````````````-<"```2````````
 M`````````````````)4!```2`````````````````````````,(!```2````
-M`````````````````````,D````2`````````````````````````*\"```2
-M`````````````````````````($"```2`````````````````````````.<`
-M```2`````````````````````````#X!```2````````````````````````
-M`&,````2`````````````````````````&D"```2````````````````````
+M`````````````````````!0!```2`````````````````````````*\"```2
+M`````````````````````````($"```2`````````````````````````/P`
+M```2`````````````````````````&P!```2````````````````````````
+M`%<````2`````````````````````````&D"```2````````````````````
 M`````-`!```2`````````````````````````'$"```2````````````````
-M`````````"8"```2`````````````````````````!,!```2````````````
-M`````````````)H!```2`````````````````````````#(!```2````````
+M`````````"8"```2`````````````````````````#\!```2````````````
+M`````````````)H!```2`````````````````````````&`!```2````````
 M`````````````````,<"```2``````````````````````````("```2````
-M`````````````````````$8````1`````````````````````````"T!```2
-M`````````````````````````(P````2`````````````````````````$4!
+M`````````````````````&X````1``````````````````````````\!```2
+M`````````````````````````&,````2`````````````````````````'L`
 M```2`````````````````````````*@!```2````````````````````````
 M`+`!```2`````````````````````````,T"```1````````````````````
 M`````-<!```2`````````````````````````,X"```A````````````````
@@ -148,14 +148,14 @@ M`````"8$```2``T`H#8````````@!P```````#<#```2``T`D"L````````\
 M`````````&@#```2``T`M"<````````4`0```````*\#```2``T`,$``````
 M```0`0`````````$```0`!<`L,`!`````````````````#H$```2``T`0#4`
 M``````!@`0````````!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)4
-M34-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!03%]D;U]U
-M;F1U;7``4&5R;%]G=E]F971C:'!V`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K
-M7VQO8VL`4&5R;%]G971?<W8`4&5R;%]N97=84P!B;V]T7T1Y;F%,;V%D97(`
-M<&5R;%]R=6X`<&5R;%]P87)S90!097)L7W-V7W-E='!V`%!E<FQ?<W9?<V5T
-M<'9N`'!E<FQ?8V]N<W1R=6-T`'!E<FQ?9&5S=')U8W0`4$Q?8W5R<F5N=%]C
-M;VYT97AT`'!E<FQ?86QL;V,`4&5R;%]C<F]A:U]N;V-O;G1E>'0`<&5R;%]F
-M<F5E`%!E<FQ?<V%F97-Y<VUA;&QO8P!097)L7W-Y<U]I;FET,P!097)L7VYE
-M=UA37V9L86=S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M`%]?
+M34-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7V%T
+M9F]R:U]L;V-K`%!E<FQ?;6=?<V5T`%!E<FQ?;F5W6%,`4$Q?9&]?=6YD=6UP
+M`%!E<FQ?<WES7VEN:70S`&)O;W1?1'EN84QO861E<@!P97)L7W)U;@!P97)L
+M7V-O;G-T<G5C=`!097)L7VYE=UA37V9L86=S`%!E<FQ?9W9?9F5T8VAP=@!P
+M97)L7W!A<G-E`'!E<FQ?86QL;V,`4&5R;%]A=&9O<FM?=6YL;V-K`'!E<FQ?
+M9&5S=')U8W0`<&5R;%]F<F5E`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?<W9?<V5T
+M<'8`4&5R;%]S>7-?=&5R;0!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V=E
+M=%]S=@!097)L7W-A9F5S>7-M86QL;V,`4$Q?8W5R<F5N=%]C;VYT97AT`%]?
 M8WAA7V9I;F%L:7IE`')E860`<W1R8VAR`&=E='!I9`!M96UM;W9E`%]?;&EB
 M8U]S=&%R=%]M86EN`%]?9G!R:6YT9E]C:&L`<W1R8VUP`&]P96XV-`!U;FQI
 M;FL`<W1R=&]K`&UE;7-E=`!S=')N8VUP`&=E='5I9`!M96UC:'(`8VQO<V5D
@@ -173,7 +173,7 @@ M<W1A<G0`7U]B<W-?<W1A<G1?7P!S:&%?=7!D871E`'AS7VEN:70`7U]E;F1?
 M7P!?7V)S<U]E;F1?7P!?7V)S<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M
 M:W1M<&1I<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G
 M`&UY7W!A<E]P;`!P87)?9&EE`'!A<E]I;FET7V5N=@!'3$E"0U\R+C$W`$=,
-M24)#7S(N,S0`1TQ)0D-?,BXS,P`O=7-R+VQI8B]P97)L-2\U+C,V+V-O<F5?
+M24)#7S(N,S0`1TQ)0D-?,BXS,P`O=7-R+VQI8B]P97)L-2\U+C,X+V-O<F5?
 M<&5R;"]#3U)%``````````$``@`!``$``@`"``$``0`"``(``@`!``,``0`"
 M``$``@`"``(``@`"``$``@`!``$``@`"``0``@`"``(``0`!``$``0`"``$`
 M`0`"``(``@`"``(``0`"``(``0`"``$`!``"``(``@`!``(``0`"``(``0`"
@@ -231,15 +231,15 @@ MJ=```-`1VD;Y$,(VD2`"']8?(`/5'R`#U1\@`]70``#0$=Y&^1#B-I$@`A_6
 MT```T!'B1OD0`C>1(`(?UM```-`1YD;Y$"(WD2`"'];]>[JIPP``T&,<1_G]
 M`P"1\U,!J?5;`JGBAP.IXN,`D>$#`9'@3P"YX#,!D60`0/GD+P#Y!`"`TL,`
 M`-!CX$?Y8``_UL(``-!"!$?YP```T`!P1_GA`P*JPP``T&.L1_E@`#_6P```
-MT`#41_D``$`Y@`H`-,```-``:$?Y0=`[U=,``/`B:&#X]$]`N4$H4CF`$@`1
-ME`X`$2$$`#)!*!(YP0``T"'(1_D`?'V3(``_UN,#`*KF(T#YP```\&)"`I'E
+MT`#41_D``$`Y@`H`-,```-``:$?Y0=`[U=,``/`B:&#X]$]`N4%H4CF`$@`1
+ME`X`$2$$`#)!:!(YP0``T"'(1_D`?'V3(``_UN,#`*KF(T#YP```\&)"`I'E
 M3T"Y!$!`^2$``+#'`$#Y(6`DD2```+``@"219P0`J4,$`/ED``&IOP0`<<T*
 M`%0A`(#2'R`#U2`,`!'$>&'X(00`D638(/B_``%K;/__5*4,`!%U0@*1?]@E
 M^,4``-"E^$;Y`0``L*`.0/GB`Q0J(0`<D00`@-*@`#_6(`8`-'5"`I'V4P&1
 MP0``T"&@1_F@#D#Y(``_UO0#`"KA`Q:J(```L`#`&9&.``"40`4`M'-"`I'!
 M``#0(>Q&^6`.0/D@`#_6P```T`!D1_D``#_6P```T``<1_GB+T#Y`0!`^4(`
 M`>L!`(#2H04`5/5;0JG@`Q0J\U-!J?U[QJC``U_6P```T`!(1_G3``#P```_
-MUF)"`I%`#`#YH`,`M,$``-`A?$?Y(``_UL```-``:$?Y0=`[U2)H8/A?W"@Y
+MUF)"`I%`#`#YH`,`M,$``-`A?$?Y(``_UL```-``:$?Y0=`[U2)H8/A?."8Y
 MHO__%Z`.0/G!``#0(1A'^2``/];,__\7H`I`^6```+1U"`"4U/__%^$#%JH@
 M``"P`.`7D5P``)2@"@#YP/G_M&T(`)3,__\7A0"`4K/__Q?!``#0(3!'^2``
 M@%(@`#_6P```T`"81_D``#_6'R`#U1\@`]4?(`/5'R`#U1\@`]4?(`/5'R`#
